pub struct VerilatedModelConfig {
pub verilator_optimization: usize,
pub ignored_warnings: Vec<String>,
pub enable_tracing: bool,
pub cxx_standard: Option<CxxStandard>,
}Expand description
Configuration for a particular [VerilatedModel].
Fields
verilator_optimization: usizeIf None, there will be no optimization. If a value from 0 to 3
inclusive, the flag -O<level> will be passed. Enabling will slow
compilation times.
ignored_warnings: Vec<String>A list of Verilator warnings to disable on the Verilog source code for this model.
enable_tracing: boolWhether this model should be compiled with tracing support.
cxx_standard: Option<CxxStandard>Optionally specify the C++ standard used by Verilator.