pub trait DpiFunction: Sync {
// Required methods
fn name(&self) -> &'static str;
fn signature(&self) -> &'static [(&'static str, &'static str)];
fn pointer(&self) -> *const c_void;
}Expand description
A &'static dyn DpiFunction represents a Rust function suitable for use in
Verilator DPI. See the #[verilog::dpi]
macro for details.
Required Methods
Sourcefn name(&self) -> &'static str
fn name(&self) -> &'static str
The Rust-declared name of the DPI function. This should be taken to be equivalent to the name given for the DPI C function in Verilog source code.